@@ -10,14 +10,12 @@
 # General method
 #
 
-#' @inherit matrixStats::colAnyNAs
-#' @importMethodsFrom DelayedArray seed
-#' @rdname colAnyNAs
-#' @author Peter Hickey
+
+#' @rdname DelayedMatrixStats-deprecated
 #' @export
 setMethod("colAnyMissings", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, force_block_processing = FALSE,
-                   ..., useNames = NA) {
+                   ..., useNames = TRUE) {
             colAnyNAs(x = x,
                     rows = rows,
                     cols = cols,
@@ -31,9 +29,10 @@ setMethod("colAnyMissings", "DelayedMatrix",
 # Seed-aware methods
 #
 
+#' @rdname DelayedMatrixStats-deprecated
 #' @export
 setMethod("colAnyMissings", "matrix",
-          function(x, rows = NULL, cols = NULL, ..., useNames = NA) {
+          function(x, rows = NULL, cols = NULL, ..., useNames = TRUE) {
             colAnyNAs(x = x,
                       rows = rows,
                       cols = cols,
