@@ -8,7 +8,7 @@
 
 .DelayedMatrix_block_colCounts <- function(x, rows = NULL, cols = NULL,
                                            value = TRUE, na.rm = FALSE,
-                                           ..., useNames = NA) {
+                                           ..., useNames = TRUE) {
   # Check input type
   stopifnot(is(x, "DelayedMatrix"))
   DelayedArray:::.get_ans_type(x, must.be.numeric = FALSE)
@@ -26,9 +26,7 @@
   if (length(val) == 0L) {
     return(numeric(ncol(x)))
   }
-  # NOTE: Return value of matrixStats::colCounts() has no names
-  # TODO: Obey top-level `useNames` argument.
-  unlist(val, recursive = FALSE, use.names = FALSE)
+  unlist(val, recursive = FALSE, use.names = useNames)
 }
 
 ### ----------------------------------------------------------------------------
@@ -47,7 +45,6 @@
 #' @export
 #' @template example_dm_matrix
 #' @template example_dm_S4VectorsDF
-#' @template useNamesParameter
 #' @author Peter Hickey
 #' @examples
 #'
@@ -56,7 +53,7 @@
 #' colCounts(dm_matrix, rows = 1:4, value = 1)
 setMethod("colCounts", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, value = TRUE, na.rm = FALSE,
-                   force_block_processing = FALSE, ..., useNames = NA) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
             .smart_seed_dispatcher(x, generic = MatrixGenerics::colCounts,
                                    blockfun = .DelayedMatrix_block_colCounts,
                                    force_block_processing = force_block_processing,
