@@ -7,7 +7,7 @@
 ###
 
 .DelayedMatrix_block_colIQRs <- function(x, rows = NULL, cols = NULL,
-                                         na.rm = FALSE, ..., useNames = NA) {
+                                         na.rm = FALSE, ..., useNames = TRUE) {
   # Check input type
   stopifnot(is(x, "DelayedMatrix"))
   DelayedArray:::.get_ans_type(x, must.be.numeric = FALSE)
@@ -24,9 +24,7 @@
   if (length(val) == 0L) {
     return(numeric(ncol(x)))
   }
-  # NOTE: Return value of matrixStats::colIQRs() has no names
-  # TODO: Obey top-level `useNames` argument.
-  unlist(val, recursive = FALSE, use.names = FALSE)
+  unlist(val, recursive = FALSE, use.names = useNames)
 }
 
 ### ----------------------------------------------------------------------------
@@ -42,7 +40,6 @@
 #' @rdname colIQRs
 #' @template common_params
 #' @template lowercase_x
-#' @template useNamesParameter
 #' @export
 #' @template example_dm_matrix
 #' @template example_dm_MatrixMatrix
@@ -52,7 +49,7 @@
 #' colIQRs(dm_matrix)
 setMethod("colIQRs", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, na.rm = FALSE,
-                   force_block_processing = FALSE, ..., useNames = NA) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
             .smart_seed_dispatcher(x, generic = MatrixGenerics::colIQRs,
                                    blockfun = .DelayedMatrix_block_colIQRs,
                                    force_block_processing = force_block_processing,
