@@ -8,7 +8,7 @@
 
 .DelayedMatrix_block_colLogSumExps <- function(lx, rows = NULL, cols = NULL,
                                                na.rm = FALSE,
-                                               ..., useNames = NA) {
+                                               ..., useNames = TRUE) {
   # Check input type
   stopifnot(is(lx, "DelayedMatrix"))
   DelayedArray:::.get_ans_type(lx, must.be.numeric = TRUE)
@@ -25,9 +25,7 @@
   if (length(val) == 0L) {
     return(numeric(ncol(lx)))
   }
-  # NOTE: Return value of matrixStats::colLogSumExps() has names
-  # TODO: Obey top-level `useNames` argument.
-  unlist(val, recursive = FALSE, use.names = TRUE)
+  unlist(val, recursive = FALSE, use.names = useNames)
 }
 
 ### ----------------------------------------------------------------------------
@@ -43,7 +41,6 @@
 #' @rdname colLogSumExps
 #' @template common_params
 #' @template lx
-#' @template useNamesParameter
 #' @export
 #' @author Peter Hickey
 #' @examples
@@ -51,7 +48,7 @@
 #' colLogSumExps(log(x))
 setMethod("colLogSumExps", "DelayedMatrix",
           function(lx, rows = NULL, cols = NULL, na.rm = FALSE,
-                   force_block_processing = FALSE, ..., useNames = NA) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
             .smart_seed_dispatcher(lx, generic = MatrixGenerics::colLogSumExps,
                                    blockfun = .DelayedMatrix_block_colLogSumExps,
                                    force_block_processing = force_block_processing,
