@@ -8,7 +8,7 @@
 
 .DelayedMatrix_block_colVars <- function(x, rows = NULL, cols = NULL,
                                          na.rm = FALSE, center = NULL,
-                                         ..., useNames = NA) {
+                                         ..., useNames = TRUE) {
   # Check input type
   stopifnot(is(x, "DelayedMatrix"))
   DelayedArray:::.get_ans_type(x, must.be.numeric = TRUE)
@@ -48,7 +48,6 @@
 #' @rdname colVars
 #' @template common_params
 #' @template lowercase_x
-#' @template useNamesParameter
 #' @export
 #' @template example_dm_matrix
 #' @template example_dm_HDF5
@@ -58,7 +57,7 @@
 #' colVars(dm_matrix)
 setMethod("colVars", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
-                   force_block_processing = FALSE, ..., useNames = NA) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
             .smart_seed_dispatcher(x, generic = MatrixGenerics::colVars,
                                    blockfun = .DelayedMatrix_block_colVars,
                                    force_block_processing = force_block_processing,
