@@ -21,7 +21,7 @@
 #' colWeightedSds(dm_Rle, w = 1 / rowMeans2(dm_Rle))
 setMethod("colWeightedSds", "DelayedMatrix",
           function(x, w = NULL, rows = NULL, cols = NULL, na.rm = FALSE,
-                   force_block_processing = FALSE, ..., useNames = NA) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
             sqrt(colWeightedVars(
               x = x,
               w = w,
