@@ -10,13 +10,11 @@
 # General method
 #
 
-#' @inherit matrixStats::rowAnyMissings
-#' @importMethodsFrom DelayedArray seed
-#' @rdname colAnyNAs
+#' @rdname DelayedMatrixStats-deprecated
 #' @export
 setMethod("rowAnyMissings", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, force_block_processing = FALSE,
-                   ..., useNames = NA) {
+                   ..., useNames = TRUE) {
             rowAnyNAs(x = x,
                     rows = rows,
                     cols = cols,
@@ -30,9 +28,10 @@ setMethod("rowAnyMissings", "DelayedMatrix",
 # Seed-aware methods
 #
 
+#' @rdname DelayedMatrixStats-deprecated
 #' @export
 setMethod("rowAnyMissings", "matrix",
-          function(x, rows = NULL, cols = NULL, ..., useNames = NA) {
+          function(x, rows = NULL, cols = NULL, ..., useNames = TRUE) {
             rowAnyNAs(x = x,
                       rows = rows,
                       cols = cols,
