@@ -7,7 +7,7 @@
 ###
 
 .DelayedMatrix_block_rowOrderStats <- function(x, rows = NULL, cols = NULL,
-                                               which, ..., useNames = NA) {
+                                               which, ..., useNames = TRUE) {
   # Check input type
   stopifnot(is(x, "DelayedMatrix"))
   DelayedArray:::.get_ans_type(x, must.be.numeric = TRUE)
@@ -24,9 +24,7 @@
   if (length(val) == 0L) {
     return(numeric(ncol(x)))
   }
-  # NOTE: Return value of matrixStats::rowOrderStats() has no names
-  # TODO: Obey top-level `useNames` argument.
-  unlist(val, recursive = FALSE, use.names = FALSE)
+  unlist(val, recursive = FALSE, use.names = useNames)
 }
 
 ### ----------------------------------------------------------------------------
@@ -48,7 +46,7 @@
 #' rowOrderStats(dm_Matrix, which = 2)
 setMethod("rowOrderStats", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, which,
-                   force_block_processing = FALSE, ..., useNames = NA) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
             .smart_seed_dispatcher(x, generic = MatrixGenerics::rowOrderStats,
                                    blockfun = .DelayedMatrix_block_rowOrderStats,
                                    force_block_processing = force_block_processing,
