@@ -1,4 +1,4 @@
-## ---- include = FALSE, setup--------------------------------------------------
+## ----include = FALSE, setup---------------------------------------------------
 knitr::opts_chunk$set(echo = TRUE, comment = "#>", collapse = TRUE,
                       message = FALSE)
 library(BiocStyle)
@@ -160,3 +160,6 @@ system.time(sin_dm_matrix <- sin(dm_matrix))
 ## ----colSums2_sin-------------------------------------------------------------
 all.equal(colSums2(sin_dm_matrix), colSums(sin(as.matrix(dm_matrix))))
 
+## -----------------------------------------------------------------------------
+sessionInfo()
+
