@@ -45,7 +45,7 @@ testDefaultArgs <- function(matrix_list, DelayedMatrix_list) {
   test_that("Default arguments", {
     check.attributes <- checkAttributes(DelayedMatrix_list)
     expecteds <- Map(mg_f, matrix_list)
-    observeds <- Map(dms_f, DelayedMatrix_list)
+    observeds <- Map(dmg_f, DelayedMatrix_list)
     Map(expect_equal, observeds, expecteds, check.attributes = check.attributes)
   })
 }
@@ -65,7 +65,7 @@ testNonNullRowsAndCols <- function(matrix_list, DelayedMatrix_list) {
       rows = rows_list,
       cols = cols_list)
     observeds <- Map(
-      f = dms_f,
+      f = dmg_f,
       DelayedMatrix_list,
       rows = rows_list,
       cols = cols_list)
@@ -80,13 +80,13 @@ testGroup <- function(matrix_list, DelayedMatrix_list) {
     DelayedMatrix_list <- DelayedMatrix_list[
       grep("base_case", names(DelayedMatrix_list))]
     check.attributes <- checkAttributes(DelayedMatrix_list)
-    if (any(grepl("col", body(dms_f)))) {
+    if (any(grepl("col", body(dmg_f)))) {
       group_list <- list(c(1, 2, 2, 2))
     } else {
       group_list <- list(c(1, 1, 2))
     }
     expecteds <- Map(mg_f, matrix_list, group = group_list)
-    observeds <- Map(dms_f, DelayedMatrix_list, group = group_list)
+    observeds <- Map(dmg_f, DelayedMatrix_list, group = group_list)
     Map(expect_equal_DA, observeds, expecteds,
         check.attributes = check.attributes)
   })
@@ -100,20 +100,9 @@ for (i in seq_len(nrow(test_manifest))) {
 
   # Get the function to be tested
   f <- test_manifest[i, "Function"]
-
-  # This hack is to preserve the `useNames = FALSE` behaviour of
-  # colAnyMissings/rowAnyMissings in BioC <= BioC 3.17 and matrixStats < 1.0.0
-  # in BioC == 3.17 with matrixStats == 1.0.0.
-  # colAnyMissings/rowAnyMissings are effectively aliases for
-  # colAnyNAs/rowAnyNAs and will be deprecated in the next release.
-  if (f == "colAnyMissings") {
-    f <- "colAnyNAs"
-  } else if (f == "rowAnyMissings") {
-    f <- "rowAnyNAs"
-  }
   # A clunky hack to get MatrixGenerics::f
   mg_f <- get(f, envir = environment(MatrixGenerics::colSums2))
-  dms_f <- get(f)
+  dmg_f <- get(f)
   context(f)
 
   # Filter out those storage modes not to be tested
